<?php
/* (c) 2007, Andreas Forstinger, www.mobilemoodle.org */
global $CFG, $USER, $COURSE;
require_once ($CFG->dirroot . '/mod/choice/lib.php'); // choice support

// get parameters
$choiceid = optional_param('choiceid', null, PARAM_INTEGER); // id of choice

// get choice object
if (!$choice = choice_get_choice($choiceid)) {
    momo_print_error('error_parameter');
}

/// handle authentication
momo_login_to_course($choice->course);

// get course module object
if (!$cm = get_coursemodule_from_instance('choice', $choiceid)) {
    momo_print_error('error_parameter');
}

// check which of the possible options was selected
$vote = optional_param('option', null);
$noselection = ($vote == null) ? true : false;

// get possible previous answer
$answer = get_record('choice_answers', 'choiceid', $choiceid, 'userid', $USER->id);

$limit_exceeded = false;
$success = false;
$message = 'msg_choice_error';
if (!$noselection) { // user has chosen an option on previous screen
    if ($answer) { // update existing record
        if (isOptionAllowed($choice, $vote)) { // we only have to react on change
            $newanswer = $answer;
            $newanswer->optionid = $vote;
            $newanswer->timemodified = time();
            if (update_record('choice_answers', $newanswer)) {
                $success = true;
                $message = 'msg_choice_updated';
                // add log message, needed for statistics
                add_to_log($COURSE->id, 'choice', 'choose again', "view.php?id=$cm->id", $choice->id, $cm->id);
            } else {
                momo_log('choice update failed', 'choice');
            }
        } else { // optional limit is exceeded
            $limit_exceeded = true;
            $message = 'msg_choice_limit_exceeded';
        }
    } else { // new answer
        if (isOptionAllowed($choice, $vote)) {
            $newanswer = new object;
            $newanswer->choiceid = $choice->id;
            $newanswer->userid = $USER->id;
            $newanswer->optionid = $vote;
            $newanswer->timemodified = time();
            if (insert_record("choice_answers", $newanswer)) {
                $success = true;
                $message = 'msg_choice_saved';
                // add log message, needed for statistics
                add_to_log($COURSE->id, 'choice', 'choose', "view.php?id=$cm->id", $choice->id, $cm->id);
            } else {
                momo_log('choice failed', 'choice');
            }
        } else { // optional limit is exceeded
            $limit_exceeded = true;
            $message = 'msg_choice_limit_exceeded';
        }
    }
} else {
    $message = 'msg_choice_no_selection';
}

// check if results should be shown
$show_results = false;
if ($choice->showresults == CHOICE_SHOWRESULTS_ALWAYS || $choice->showresults == CHOICE_SHOWRESULTS_AFTER_ANSWER) {
    $show_results = true;
}

/**
 * This function checks back if the given option is still allowed in the
 * given choice or if a possibly configured limit is already reached.
 * Note: this function does not cover concurrency handling
 * @param choice - the choice object
 * @param option - the option to check
 * @return returns true if the given option is still allowed, false if not
 *
 */
function isOptionAllowed($choice, $option) {
    $returnvalue = false;
    // check if limit is set
    if (!$choice->limitanswers) {
        $returnvalue = true;
    } else {
        // count given answers
        $countanswers = countAnswers($choice, $option);
        // get maximum allowed answers
        $maxans = $choice->maxanswers[$option];
        // compare
        if ($countanswers < $maxans) { // allow
            $returnvalue = true;
        }
    }
    return $returnvalue;
}

/**
 * This function counts the answers similar to $option in $choice
 * @param $choice the choice in which to count answers
 * @param $option the option to count the answers for
 * @return returns the number of answers
 */
function countAnswers($choice, $option) {
    // get existing answers
    $countanswers = get_records_select('choice_answers', "choiceid=$choice->id and optionid=$option");
    if ($countanswers) {
        $countans = 0;
        foreach ($countanswers as $ca) { //only return enrolled users. (no creators or admins)
            if (isstudent($choice->course, $ca->userid) or isteacher($choice->course, $ca->userid)) {
                $countans = $countans +1;
            }
        }
        $countanswers = count($countans);
    } else {
        $countanswers = 0;
    }
    return $countanswers;
}

/// output
?>
<ps t="<?php print_string('modulename','choice')?>" s="false" bo="false" back="choice/choice.php&amp;id=<?php echo($choice->id)?>">
<pa>
<?php momo_print_header($choice->name, 'mod_choice') ?>
<font class="h3"/><?php momo_print_string($message)?><font class="std"/><br align="left"/>
<?php


if ($success) {
    if ($show_results) {
?>


<font class="h2"/>
<?php momo_print_string('lbl_choice_result')?>
<font class="std"/><br/>
<?php


        // print out result for every option
        foreach ($choice->option as $optionid => $optiontext) {
?>
<?php echo($optiontext)?> -> <?php echo(countAnswers($choice,$optionid))?><br/>
<?php


        }
    } else {
?>


<?php momo_print_string('msg_choice_results_not_public')?><br/>
<?php } ?>
<?php

    }
else { // there was an error
?>

<?php } ?>
</page>
</pagesuite>